SidebarController class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
handleMainItemTap(NavigationItem item, int index, dynamic onRouteSelected(String)?, String? currentRoute, dynamic onRoute)
→ void
-
-
handleSubItemTap(NavigationItem item, int index, int subIndex, dynamic onRouteSelected(String)?, String? currentRoute, bool onRoute)
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateFromRoute(String? currentRoute, List items)
→ void
-