ItemConfig class

Configuration for styling individual navigation items.

Constructors

ItemConfig({Color? selectedItemColor, Color? iconBagroundColor, Color? iconColor, Color? textColor})
Creates a configuration for navigation item styling.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconBagroundColor → Color?
The background color for the icon container. Note: "iconBagroundColor" appears to have a typo - consider renaming to "iconBackgroundColor"
final
iconColor → Color?
The color to use for the icon itself.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedItemColor → Color?
The color to use when an item is selected.
final
textColor → Color?
The color to use for the item's text label.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited