SidebarConfig class

Configuration for an item in the navigation widget.

Constructors

SidebarConfig({Color? backgroundColor, double? width, EdgeInsets? padding = const EdgeInsets.symmetric(vertical: 12, horizontal: 8)})
const

Properties

backgroundColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
padding → EdgeInsets?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited